Weblate
=======

`Weblate <https://weblate.org/>`__ is available at
`weblate.example.com`. The user with administrative rights and the
contact email are defined as documented in `this file
<https://lab.enough.community/main/infrastructure/blob/master/playbooks/weblate/roles/weblate/defaults/main.yml>`__
and can be modified in the
`~/.enough/example.com/inventory/host_vars/weblate-host/secrets.yml`
file.
